@@ -143,7 +143,22 @@ pub fn create_server<S>(storage: S) -> QueueHandle
 where
     S: Storage + Sync + 'static,
 {
-    let arbiter = Arbiter::current();
+    create_server_in_arbiter_handle(Arbiter::current(), storage)
+}
+
+/// Create a new server in the provided Arbiter
+pub fn create_server_in_arbiter<S>(arbiter: &Arbiter, storage: S) -> QueueHandle
+where
+    S: Storage + Sync + 'static,
+{
+    create_server_in_arbiter_handle(arbiter.handle(), storage)
+}
+
+/// Create a new server in the provided ArbiterHandle
+pub fn create_server_in_arbiter_handle<S>(arbiter: ArbiterHandle, storage: S) -> QueueHandle
+where
+    S: Storage + Sync + 'static,
+{
     QueueHandle {
         inner: Server::new(&arbiter, storage),
         arbiter,
@@ -256,11 +271,14 @@ impl QueueHandle {
     {
         let job = new_job(job)?;
         let server = self.inner.clone();
-        self.arbiter.spawn(async move {
+        let success = self.arbiter.spawn(async move {
             if let Err(e) = server.new_job(job).await {
                 error!("Error creating job, {}", e);
             }
         });
+        if !success {
+            return Err(anyhow::anyhow!("Failed to queue job"));
+        }
         Ok(())
     }
 
@@ -274,11 +292,14 @@ impl QueueHandle {
     {
         let job = new_scheduled_job(job, after)?;
         let server = self.inner.clone();
-        self.arbiter.spawn(async move {
+        let success = self.arbiter.spawn(async move {
             if let Err(e) = server.new_job(job).await {
                 error!("Error creating job, {}", e);
             }
         });
+        if !success {
+            return Err(anyhow::anyhow!("Failed to schedule job"));
+        }
         Ok(())
     }
 
